@@ -1,9 +1,14 @@
-def printexecutiontime(message):
+"""
+Defines the printexecutiontime decorator
+"""
+
+from datetime import datetime
+
+def printexecutiontime(message, display=print):
     '''
     This function returns a decorator. This allows to have a decorator that accepts parameters.
-    meesage: A string with a '{0}' placeholder for the time that will be sent to the console.
+    message: A string with a '{0}' placeholder for the time that will be sent to the console.
     '''
-    from datetime import datetime
     def decorator(function):
         '''
         The decorator itself returns a wrapper function that will replace the original one.
@@ -12,10 +17,10 @@ def printexecutiontime(message):
             '''
             This wrapper calculates and displays the execution time of the function.
             '''
-            start = datetime.now()
+            start = datetime.utcnow()
             value = function(*args, **kwargs)
-            elapsed = datetime.now() - start
-            print(message.format(elapsed))
+            elapsed = datetime.utcnow() - start
+            display(message.format(elapsed))
             return value
         return wrapper
     return decorator
